@@ -4,7 +4,7 @@ use warnings;
 
 package Art::World {
 
-  our $VERSION = '0.18_06';
+  our $VERSION = '0.18_07';
 
   use Zydeco
     authority => 'cpan:SMONFF',
@@ -487,7 +487,7 @@ __END__
 
 =head1 NAME
 
-Art::World - Agents interactions modeling
+Art::World - Modeling of creative processes
 
 =head1 SYNOPSIS
 
@@ -503,6 +503,10 @@ Art::World - Agents interactions modeling
 C<Art::World> is an attempt to model and simulate a system describing the
 interactions and influences between the various I<agents> of the art world.
 
+It tries to draw a schematization of the interactions between art, institutions,
+influences and unexpected parameters during the social processes of artistic
+creation.
+
 More informations about the purposes and aims of this project can be found in
 it's L<Art::World::Manual>. Especially, the
 L<HISTORY|Art::World::Manual/"HISTORY"> and the
@@ -647,14 +651,14 @@ The C<Agent> got an a C<networking( $people )> method. When it is passed and
 C<ArrayRef> of various implementation classes of C<Agents> (C<Artist>,
 C<Curator>, etc.) it bumps the C<reputation> attributes of all of 1/10 of the
 C<Agent> with the highest reputation. If this reputation is less than 1, it is
-rounded to the C<$self->config->{ FAME }->{ DEFAULT_BUMP }> constant.
+rounded to the C<< $self->config->{ FAME }->{ DEFAULT_BUMP } >> constant.
 
-The bump coefficient can be adjusted in the configuration through C<{ FAME }->{
-BUMP_COEFFICIENT }>.
+The bump coefficient can be adjusted in the configuration through C<< { FAME }->{
+BUMP_COEFFICIENT } >>.
 
 There is also a special way of bumping fame when C<Manager>s are in a Networking
 activity: The C<influence()> method makes possible to apply the special
-C<$self->config->{ FAME }->{ MANAGER_BUMP }> constant. Then the C<Agent>s
+C<< $self->config->{ FAME }->{ MANAGER_BUMP } >> constant. Then the C<Agent>s
 reputations are bumped by the C<MANAGER_BUMP> value multiplicated by the highest
 networking C<Manager> reputation. This is what the C<influence()> method
 returns:
@@ -699,7 +703,7 @@ C<discourse>, C<file>, C<idea>, C<process>, C<project> and C<time>.
 =head2 Artwork
 
 The base thing producted by artists. Artwork is subclass of
-L<C<Work>Art::World::Work> that have a C<Showable> and C<Collectionable> role.
+L<C<Work>|Art::World#Work> that have a C<Showable> and C<Collectionable> role.
 
 =head2 Book
 
@@ -817,7 +821,7 @@ Thanks to everyone who has contributed to ack in any way, including Adrien
 Lucca, Toby Inkster, Ezgi Göç, Pierre Aubert, Seb. Hu-Rillettes, Joseph Balicki,
 Nicolas Herubel and Nadia Boursin-Piraud.
 
-This project was made possible by the greatness of the L<Zydeco|https://zydeco.toby.ink/> .
+This project was made possible by the greatness of the L<Zydeco|https://zydeco.toby.ink/> toolkit.
 
 =head2 MOTIVATIONS
 
